## converting SL data from Corey to taxonomy file
library(readr)
library(dplyr)
library(lubridate)

dat <- read_csv("SierraLeone_Cholera_2012_Public.csv") %>%
mutate(TL = as.Date(Date_seen,format="%m/%d/%y"),
TR= TL,
who_region = "AFR",
ISO_A1 = "SLE"
) %>%
rename(sCh=Case_count,
ISO_A2_L2 = District,
ISO_A2_L3 = Chiefdom)

district_chiefdom <- dat %>% select(ISO_A2_L3,ISO_A2_L2,Chiefdom_code) %>% distinct

## fill in zeros since they are meant to be there (according to MoH)
date_seq <- seq.Date(min(dat$TL),max(dat$TL),by="day")
chiefdoms <- unique(dat$ISO_A2_L3)

library(purrr)
fillers <- expand.grid(ISO_A2_L3 = chiefdoms, TL = date_seq) %>% data.frame
fillers <- left_join(fillers,district_chiefdom)

dat <- left_join(fillers,dat)

dat <- dat %>% mutate(ISO_A2_L1 = case_when(
  ISO_A2_L2 %in% c("Kailahun","Kono","Kenema") ~ "SL-E",
  ISO_A2_L2 %in% c("Bombali","Kambia","Koinadugu","Port Loko","Tonkolili") ~ "SL-N",
  ISO_A2_L2 %in% c("Bo", "Bonthe", "Moyamba", "Pujehun") ~ "SL-S",
  ISO_A2_L2 %in% c("Western Area Rural","Western Area Urban") ~ "SL-W")
) %>%
select(-Date_seen) %>%
mutate(TR = TL,who_region = "AFR",ISO_A1 = "SLE",sCh = ifelse(is.na(sCh),0,sCh)) %>%
dplyr::mutate(Primary = TRUE, Phantom = "")

write_csv(dat,"SLE_2012_dat.csv")

